@@ -13,7 +13,7 @@ public:
 	IPv4Address(IPv4Address &na) { a=na.toStruct(); }
 	bool operator==( const IPv4Address & ) const;
 	bool operator!=( const IPv4Address & ) const;
-	char * IPv4Address::ptr() const;
+	char * ptr() const;
 	friend ostream & operator<<( ostream &, const IPv4Address &);
 	struct in_addr toStruct() const;
 private:
